<?php 
App::import('Helper', 'Html');
App::import('Helper', 'Javascript');
App::import('Helper', 'AppForm');
App::import('Controller', 'Schedules');

class AppFormHelperTest extends CakeTestCase {
	var $fixtures = array('app.schedule');
	var $AppForm = null;

	function start() {
		parent::start();
		Router::reload();

		$this->AppForm =& new AppFormHelper();
		$this->AppForm->Html =& new HtmlHelper();
		$this->AppForm->Javascript =& new JavascriptHelper();
		$this->Controller =& new SchedulesController();
		$this->Controller->constructClasses();
		$this->View =& new View($this->Controller);
		ClassRegistry::addObject('view', $view);
	}

	function testFormCreate() {
		$result = $this->AppForm->create('Schedule', array('url' => '/schedules/add'));
		$expected = array(
			'form' => array('method' => 'post', 'action' => '/schedules/add'),
			'fieldset' => array('style' => 'display:none;'),
			array('input' => array('type' => 'hidden', 'name' => '_method', 'value' => 'POST')),
			'/fieldset',
			'table' => array('class'=>'form')
		);
		$this->assertTags($result, $expected,true);
	}
	function testFormEnd() {
		$result = $this->AppForm->end();
		$expected = array(
			'/table',
			'/form'
		);
		$this->assertTags($result, $expected);
	}
	function testFormTextInput() {
		$locale = Configure::write('Config.language', 'en');
		$this->AppForm->create('Schedule', array('url' => '/schedules/add'));

		$result = $this->AppForm->input('title');
		$expected = array(
			'<tr',
			'<th',
			'label' => array('for' => 'ScheduleTitle'),
			'Title',
			'/label',
			'/th',
			'<td',
			'div' => array('class' => 'input text required'),
			array('input' => array(
				'type' => 'text', 'name' => 'data[Schedule][title]',
				'value' => '', 'id' => 'ScheduleTitle', 'maxlength'=>'100'
			)),
			'/div',
			'/td',
			'/tr'
		);
		$this->assertTags($result, $expected, true);
	}
	function testFormEnDatetimeInput() {
		$locale = Configure::write('Config.language', 'en');
		$this->AppForm->create('Schedule', array('url' => '/schedules/add'));

		$result = $this->AppForm->input('from');
		$expected = array(
			'<tr',
			'<th',
			'label' => array('for' => 'ScheduleFrom'),
			'From',
			'/label',
			'/th',
			'<td',
			'div' => array('class' => 'input datetime required'),
			array('select' => array(
				'name' => 'data[Schedule][from][month]',
				'id' => 'ScheduleFromMonth'
			)),
			'*/select',
			'-',
			array('select' => array(
				'name' => 'data[Schedule][from][day]',
				'id' => 'ScheduleFromDay'
			)),
			'*/select',
			'-',
			array('select' => array(
				'name' => 'data[Schedule][from][year]',
				'id' => 'ScheduleFromYear'
			)),
			'*/select',
			array('select' => array(
				'name' => 'data[Schedule][from][hour]',
				'id' => 'ScheduleFromHour'
			)),
			'*/select',
			':',
			array('select' => array(
				'name' => 'data[Schedule][from][min]',
				'id' => 'ScheduleFromMin'
			)),
			'*/select',
			array('select' => array(
				'name' => 'data[Schedule][from][meridian]',
				'id' => 'ScheduleFromMeridian'
			)),
			'*/select',
			'/div',
			'/td',
			'/tr'
		);
		$this->assertTags($result, $expected);
	}
	function testFormJaDatetimeInput() {
		$locale = Configure::write('Config.language', 'ja');
		$this->AppForm->create('Schedule', array('url' => '/schedules/add'));

		$result = $this->AppForm->input('from');
		$expected = array(
			'<tr',
			'<th',
			'label' => array('for' => 'ScheduleFrom'),
			'*/label',
			'/th',
			'<td',
			'div' => array('class' => 'input datetime required'),
			array('select' => array(
				'name' => 'data[Schedule][from][year]',
				'id' => 'ScheduleFromYear'
			)),
			'*/select',
			array('select' => array(
				'name' => 'data[Schedule][from][month]',
				'id' => 'ScheduleFromMonth'
			)),
			'*/select',
			array('select' => array(
				'name' => 'data[Schedule][from][day]',
				'id' => 'ScheduleFromDay'
			)),
			'*/select',
			array('select' => array(
				'name' => 'data[Schedule][from][hour]',
				'id' => 'ScheduleFromHour'
			)),
			'*/select',
			':',
			array('select' => array(
				'name' => 'data[Schedule][from][min]',
				'id' => 'ScheduleFromMin'
			)),
			'*/select',
			'/div',
			'/td',
			'/tr'
		);
		$this->assertTags($result, $expected);
//var_dump(h($result));
	}
	function testDeleteButton() {
		$locale = Configure::write('Config.language', 'en');
		$result = $this->AppForm->delete_button('/schedules/delete/1');
		$expected = '<input type="button" value="Delete" onclick="javascript:delete_submit(&#039;Are you sure you want to delete&#039;,&#039;/schedules/delete/1&#039;);" />';
		$this->assertEqual($result, $expected);

		$view =& ClassRegistry::getObject('view');
		$this->assertEqual('<script type="text/javascript">'."\n".'//<![CDATA['."\n".'
			function delete_submit(confirm, url) {
				if(window.confirm(confirm)) {
					location.href = url;
				}
			} 
		'."\n" . '//]]>' . "\n".'</script>',
			$view->__scripts[0]);

	}
}
?>
